Crate cosmian_kms_base_hsm

Crate cosmian_kms_base_hsm 

Copyright 2025 Cosmian Tech SAS

Modules

hsm_capabilities
test_helpers
tests_shared
Shared HSM test suite used by vendor crates to avoid duplication. Each vendor crate provides a small config and delegates to these helpers.

Macros

aes_key_template
hsm_call
Macro to simplify HSM function calls with automatic return value checking

Structs

BaseHsm
HsmLib
A struct representing a Hardware Security Module (HSM) library interface using PKCS#11.
Info
ObjectHandlesCache
A cache structure that maps byte vectors to CK_OBJECT_HANDLE values using an LRU (Least Recently Used) strategy.
Session
A session with an HSM (Hardware Security Module) that implements PKCS#11 interface.
SlotManager
A manager for a specific PKCS#11 slot in a Hardware Security Module (HSM).

Enums

AesKeySize
HError
HsmEncryptionAlgorithm
Encryption algorithm supported by the HSM
HsmSigningAlgorithm
Signing algorithm supported by the HSM
RsaKeySize
RsaOaepDigest

Type Aliases

HResult