Copyright 2025 Cosmian Tech SAS
Modules
- hsm_
capabilities - test_
helpers - tests_
shared - Shared HSM test suite used by vendor crates to avoid duplication. Each vendor crate provides a small config and delegates to these helpers.
Macros
- aes_
key_ template - hsm_
call - Macro to simplify HSM function calls with automatic return value checking
Structs
- BaseHsm
- HsmLib
- A struct representing a Hardware Security Module (HSM) library interface using PKCS#11.
- Info
- Object
Handles Cache - A cache structure that maps byte vectors to
CK_OBJECT_HANDLEvalues using an LRU (Least Recently Used) strategy. - Session
- A session with an HSM (Hardware Security Module) that implements PKCS#11 interface.
- Slot
Manager - A manager for a specific PKCS#11 slot in a Hardware Security Module (HSM).
Enums
- AesKey
Size - HError
- HsmEncryption
Algorithm - Encryption algorithm supported by the HSM
- HsmSigning
Algorithm - Signing algorithm supported by the HSM
- RsaKey
Size - RsaOaep
Digest